@@ -460,10 +460,11 @@ class AFM (object):
         _LOG.warn(e)
         raise e
 
-    def stepper_approach(self, target_deflection):
+    def stepper_approach(self, target_deflection, record_data=None):
         _LOG.info('approach with stepper until deflection > {}'.format(
                 target_deflection))
-        record_data = _package_config['matplotlib']
+        if record_data is None:
+            record_data = _package_config['matplotlib']
         if record_data:
             position = []
             deflection = []
@@ -486,9 +487,12 @@ class AFM (object):
             axes.set_title('stepper approach {}'.format(timestamp))
             plot = axes.plot(position, deflection, 'b.-')
             figure.canvas.draw()
-            figure.show()
+            if hasattr(figure, 'show'):
+                figure.show()
             if not _matplotlib.is_interactive():
                 _matplotlib_pyplot.show()
+        if record_data:
+            return (position, deflection)
 
     def move_toward_surface(self, distance):
         """Step in approximately `distance` meters.
